package Test::For::StencillerFromUnparsedText;

1;

__END__

=pod

=head1 NAME

=head1 DESCRIPTION

:stenciller ToUnparsedText 1-test.stencil { stencils => [0, 2..4] }
